summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobiledevice.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobiledevice.h')
-rw-r--r--kmobile/kmobiledevice.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kmobile/kmobiledevice.h b/kmobile/kmobiledevice.h
index d89e3f2d..5cf19092 100644
--- a/kmobile/kmobiledevice.h
+++ b/kmobile/kmobiledevice.h
@@ -51,10 +51,10 @@ class KConfig;
* For a KMobileSomeDevice driver you have to write the following code:
* <pre>
* K_EXPORT_COMPONENT_FACTORY( libkmobile_sometqdevice, KMobileSomeDevice() );
* TQObject *KMobileSomeDevice::createObject( TQObject *tqparent, const char *name,
* const char *, const TQStringList &args )
* {
- * return new KMobileSomeDevice( tqparent, name, args );
+ * return new KMobileSomeDevice( parent, name, args );
* }
* </pre>
*
@@ -72,7 +72,7 @@ public:
/**
* Construct a new KMobileDevice.
*
* @param obj The tqparent object. This is usually 0.
* @param name The object name. For session management and window management to work.
* @param args Additional commandline parameters - the first entry has the config file name.
*/
@@ -83,16 +83,16 @@ public:
/**
* Connect to the device.
*
* @param tqparent The tqparent widget. It will be used as tqparent for message boxes.
*/
- virtual bool connectDevice( TQWidget *tqparent = 0 ) = 0;
+ virtual bool connectDevice( TQWidget *parent = 0 ) = 0;
/**
* Disconnect from the device.
*
* @param tqparent The tqparent widget. It will be used as tqparent for message boxes.
*/
- virtual bool disconnectDevice( TQWidget *tqparent = 0 ) = 0;
+ virtual bool disconnectDevice( TQWidget *parent = 0 ) = 0;
/**
* Returns true, if the tqdevice is currently connected and the link is online.
@@ -135,9 +135,9 @@ public:
/**
* Pop-up a tqdevice-specific configuration dialog.
*
* @param tqparent The tqparent widget. It will be used as tqparent for the configuration dialog.
*/
- virtual bool configDialog(TQWidget *tqparent);
+ virtual bool configDialog(TQWidget *parent);
// The ClassType may be used e.g. to select an suitable icon
enum ClassType {
@@ -51,10 +51,10 @@ class KConfig;
* <pre>
* K_EXPORT_COMPONENT_FACTORY( libkmobile_sometqdevice, KMobileSomeDevice() );
- * TQObject *KMobileSomeDevice::createObject( TQObject *tqparent, const char *name,
+ * TQObject *KMobileSomeDevice::createObject( TQObject *parent, const char *name,
* const char *, const TQStringList &args )
* {
@@ -72,7 +72,7 @@ public:
* Construct a new KMobileDevice.
*
- * @param obj The tqparent object. This is usually 0.
+ * @param obj The parent object. This is usually 0.
* @param name The object name. For session management and window management to work.
* @param args Additional commandline parameters - the first entry has the config file name.
@@ -83,16 +83,16 @@ public:
* Connect to the device.
*
- * @param tqparent The tqparent widget. It will be used as tqparent for message boxes.
+ * @param parent The parent widget. It will be used as parent for message boxes.
*/
@@ -83,16 +83,16 @@ public:
* Disconnect from the device.
*
- * @param tqparent The tqparent widget. It will be used as tqparent for message boxes.
+ * @param parent The parent widget. It will be used as parent for message boxes.
*/
@@ -135,9 +135,9 @@ public:
* Pop-up a tqdevice-specific configuration dialog.
*
- * @param tqparent The tqparent widget. It will be used as tqparent for the configuration dialog.
+ * @param parent The parent widget. It will be used as parent for the configuration dialog.
*/